module.exports = function(grunt) {
    grunt.initConfig({
        copy: {
            main: {
                files: [
                    { // Root HTML files
                        cwd: './',
                        expand: true,
                        flatten: true,
                        src: ["./*.html"],
                        dest: "./dist"
                    },
                    { // Whole folders
                        cwd: './',
                        expand: true,
                        flatten: false,
                        src: [
                            "./assets/**"
                        ],
                        dest: "./dist"
                    },
                    { // Node Modules
                        cwd: './',
                        expand: true,
                        flatten: false,
                        src: [
                            "./node_modules/html5shiv/dist/html5shiv.min.js",
                            "./node_modules/materialize-css/dist/**",
                            "./node_modules/jquery/dist/jquery.min.js"
                        ],
                        dest: "./dist/"
                    }
                ]
            }
        },
        autoprefixer: {
            options: {
                browsers: [ // https://github.com/ai/browserslist
                    'last 2 versions',
                    'Firefox >= 3',
                    'ie >= 9',
                    'Chrome >= 3',
                    'iOS >= 3'
                ]
            },
            single_file: {
                src: './style.css',
                dest: './dist/style.css'
            }
        },
        cssmin: {
            options: {
                sourceMap: false,
                ASCIIOnly: true,
                specialComments: 0,
                compatibility: 'ie9',
                roundingPrecision: false
            },
            target: {
                files: {
                    "./dist/style.css": ["./dist/style.css"] // "DEST": [FILES TO PUT IN DEST]
                }
            }
        },
        clean: {
            main: ['./dist'], // [DELETE ALL FILES IN..]
            tidy: ['./style.css', './index.html']
        },
        concat: {
            dist: {
                src: ['./dist/style.css'],
                dest: './dist/style.css'
            }
        },
        less: {
            main: {
                options: {

                },
                files: {
                    './style.css': ['./style.less']
                }
            }
        },
        pug: {
            main: {
                options: {
                    pretty: false,
                    compileDebug: false,
                    client: false,
                    data: {
                        debug: false
                    }
                },
                files: {
                    'dist/index.html': ['./index.pug'] // "DEST": [FILES TO PUT IN DEST]
                }
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-copy');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-autoprefixer');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-pug');
    grunt.loadNpmTasks('grunt-contrib-less');

    grunt.registerTask('build', ['clean:main', 'less:main', 'autoprefixer', 'concat', 'copy:main', 'pug:main', 'cssmin', 'clean:tidy']);
    grunt.registerTask('scrub', ['clean:main', 'clean:tidy']);
    return grunt.registerTask('default', ['build']);
};